Welcome to zemfrog's documentation!
======================================

.. warning::
   The project is still in ``BETA`` version, **which means that all the APIs in it are still unstable**.
   Please be careful if you want to use it in a production environment! thanks.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   auth
   user_management
   rbac
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
